@@ -3,7 +3,7 @@ from datetime import datetime, timedelta
 from typing import Any, Dict, Sequence, Type
 from uuid import uuid4
 
-from revjwt.jws import encode
+from revjwt.jwt import encode
 
 
 class PayloadDesc:
@@ -20,7 +20,7 @@ class TypDesc(PayloadDesc):
 
 class AudDesc(PayloadDesc):
     def __get__(self, instance: Any, cls: Any) -> Any:
-        return instance.client["id"]
+        return instance.client.client_id
 
 
 class IatDesc(PayloadDesc):
@@ -36,12 +36,12 @@ class JtiDesc(PayloadDesc):
 
 class SubDesc(PayloadDesc):
     def __get__(self, instance: Any, cls: Any) -> Any:
-        return instance.user["id"]
+        return instance.data["id"]
 
 
 class GrpDesc(PayloadDesc):
     def __get__(self, instance: Any, cls: Any) -> str:
-        groups = instance.user.get("groups", [])
+        groups = instance.data.get("groups", [])
         return ":".join(groups)
 
 
@@ -109,5 +109,5 @@ class JWTEncoder:
         key = self.get_private_key()
         data = self.build_payload(user)
         headers = {"kid": key}
-        encoded = encode(data, key=key, algorithm="RS256", headers=headers)  # type: ignore
+        encoded = encode(data, key=key, algorithm="RS256", headers=headers)
         return encoded
